package com.hzya.frame.cbs8.service.impl;

import cn.hutool.core.date.DateUtil;
import cn.hutool.core.map.MapBuilder;
import cn.hutool.core.util.StrUtil;
import cn.hutool.http.HttpRequest;
import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.alibaba.fastjson.serializer.SerializerFeature;
import com.hzya.frame.cbs8.dto.req.ElecRequestDTO;
import com.hzya.frame.cbs8.dto.req.PayResultRequestDTO;
import com.hzya.frame.cbs8.dto.req.TransactionDetailReqDTO;
import com.hzya.frame.cbs8.dto.res.*;
import com.hzya.frame.cbs8.service.ICbs8Service;
import com.hzya.frame.cbs8.util.CBSUtil;
import com.hzya.frame.seeyon.cbs8.entity.PaymentEntity;
import com.hzya.frame.seeyon.cbs8.service.IPaymentService;
import org.apache.commons.collections.CollectionUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import java.util.List;
import java.util.Map;

/**
 * @Description cbs8接口
 * @Author xiangerlin
 * @Date 2024/6/7 14:44
 **/
@Service
public class Cbs8ServiceImpl implements ICbs8Service {
    Logger logger = LoggerFactory.getLogger(getClass());
    @Autowired
    private IPaymentService paymentService;
    @Override
    public PayResponseDTO payApply(PaymentEntity paymentEntity) {
        Map<String, String> headerMap = MapBuilder.<String, String>create(true)
                .put("apiCode", "8000260001")
                .put("publicKey","ZJYA1vBeY1ai53iNmbAEsw6DImjkXGBkdMailxcBdliFC85Ce7eDIk+3zDUT+v578prj")
                .put("secretKey","7Gp6OjHrIaQ6R3tXGPrI4morjQyWL+qu4JJschQnkBRtv26VDgGFVYKOy5kMZfd/j3JzOP8MtA1LSGvL+2BWG8c/o7DKi92S4mr3zcGearA=")
                .put("appId","800026")
                .build();
        String body = HttpRequest.post("http://127.0.0.1:9999/kangarooDataCenterV3/entranceController/externalCallInterface").addHeaders(headerMap).body(JSONObject.toJSONString(paymentEntity)).timeout(60000).execute().body();
        PayResponseDTO payResponseDTO = JSONObject.parseObject(body,PayResponseDTO.class);
        return payResponseDTO;
    }

    /**
     * 通过业务参考号查询交易结果 3.2.6
     *
     * @param resultRequestDTO
     * @return
     * @throws Exception
     */
    @Override
    public List<PayResultResDTO> queryPayResult(PayResultRequestDTO resultRequestDTO) {
        Map<String, String> headerMap = MapBuilder.<String, String>create(true)
                .put("apiCode", "8000260002")
                .put("publicKey","ZJYA1vBeY1ai53iNmbAEsw6DImjkXGBkdMailxcBdliFC85Ce7eDIk+3zDUT+v578prj")
                .put("secretKey","7Gp6OjHrIaQ6R3tXGPrI4morjQyWL+qu4JJschQnkBRtv26VDgGFVYKOy5kMZfd/j3JzOP8MtA1LSGvL+2BWG8c/o7DKi92S4mr3zcGearA=")
                .put("appId","800026")
                .build();
        String body = HttpRequest.post("http://127.0.0.1:9999/kangarooDataCenterV3/entranceController/externalCallInterface").addHeaders(headerMap).body(JSONObject.toJSONString(resultRequestDTO)).timeout(60000).execute().body();
        if (StrUtil.isEmpty(body)){
            CbsResponseDTO cbsResponseDTO = JSONObject.parseObject(body, CbsResponseDTO.class);
            if (CollectionUtils.isNotEmpty(cbsResponseDTO.getData())){
                List<JSONObject> dataList = cbsResponseDTO.getData();
                List<PayResultResDTO> payResultList = CBSUtil.convertJsonArrayToList(dataList, PayResultResDTO.class);
                return payResultList;
            }
        }
        return null;
    }

    /**
     * 查询电子回单
     *
     * @param elecRequestDTO startDate 开始日期 - 必填
     *                       endDate 结束日期 -必填
     *                       billStatus 回单状态 1-已取回 0-未取回 ，只有已取回的才能下载
     *                       settleBusinessReferenceCode 业务参考号
     * @return List<ElecResponseDTO>
     * bucketFileUrl 回单下载地址
     * billFileName 回单文件名称
     * settleBusinessReferenceCode 业务参考号
     */
    @Override
    public List<ElecResponseDTO> queryElecBill(ElecRequestDTO elecRequestDTO) {
        if (null == elecRequestDTO){
            elecRequestDTO = new ElecRequestDTO();
        }
        if (StrUtil.isEmpty(elecRequestDTO.getStartDate())){
            elecRequestDTO.setStartDate(DateUtil.today());
        }
        if (StrUtil.isEmpty(elecRequestDTO.getEndDate())){
            elecRequestDTO.setEndDate(DateUtil.today());
        }
        String params = JSON.toJSONString(elecRequestDTO, SerializerFeature.WRITE_MAP_NULL_FEATURES, SerializerFeature.QuoteFieldNames);
        logger.info("电子回单查询请求参数为:{}", params);
        Map<String, String> headerMap = MapBuilder.<String, String>create(true)
                .put("apiCode", "8000260005")
                .put("publicKey","ZJYA1vBeY1ai53iNmbAEsw6DImjkXGBkdMailxcBdliFC85Ce7eDIk+3zDUT+v578prj")
                .put("secretKey","7Gp6OjHrIaQ6R3tXGPrI4morjQyWL+qu4JJschQnkBRtv26VDgGFVYKOy5kMZfd/j3JzOP8MtA1LSGvL+2BWG8c/o7DKi92S4mr3zcGearA=")
                .put("appId","800026")
                .build();
        String result = HttpRequest.post("http://127.0.0.1:9999/kangarooDataCenterV3/entranceController/externalCallInterface").addHeaders(headerMap).body(params).timeout(60000).execute().body();
        if (StrUtil.isNotEmpty(result)){
            CbsResponseDTO cbsResponseDTO = JSONObject.parseObject(result, CbsResponseDTO.class);
            if (null != cbsResponseDTO){
                if (CollectionUtils.isNotEmpty(cbsResponseDTO.getData())){
                    List<JSONObject> dataList = cbsResponseDTO.getData();
                    if (CollectionUtils.isNotEmpty(dataList)){
                        JSONObject jsonObject = dataList.get(0);
                        CbsResDataDTO dataDTO = JSON.toJavaObject(jsonObject, CbsResDataDTO.class);
                        List<ElecResponseDTO> elecResponseDTOList = CBSUtil.convertJsonArrayToList(dataDTO.getList(), ElecResponseDTO.class);
                        return elecResponseDTOList;
                    }
                }
            }
        }
        return null;
    }

    /**
     * 查询交易明细
     *
     * @param transactionDetailReqDTO
     * @return
     */
    @Override
    public CbsResDataDTO  queryTransactionDetail(TransactionDetailReqDTO transactionDetailReqDTO) {
        //页码
        int currentPage = transactionDetailReqDTO.getCurrentPage();
        //每页条数
        int pageSize = transactionDetailReqDTO.getPageSize();
        if (currentPage == 0){
            currentPage = CBSUtil.DEFAULT_CURRENT_PAGE;
        }
        if (pageSize == 0){
            pageSize = CBSUtil.DEFAULT_PAGE_SIZE;
            transactionDetailReqDTO.setPageSize(pageSize);
        }
        String params = JSON.toJSONString(transactionDetailReqDTO);
        Map<String, String> headerMap = MapBuilder.<String, String>create(true)
                .put("apiCode", "8000260006")
                .put("publicKey","ZJYA1vBeY1ai53iNmbAEsw6DImjkXGBkdMailxcBdliFC85Ce7eDIk+3zDUT+v578prj")
                .put("secretKey","7Gp6OjHrIaQ6R3tXGPrI4morjQyWL+qu4JJschQnkBRtv26VDgGFVYKOy5kMZfd/j3JzOP8MtA1LSGvL+2BWG8c/o7DKi92S4mr3zcGearA=")
                .put("appId","800026")
                .build();
        String result = HttpRequest.post("http://127.0.0.1:9999/kangarooDataCenterV3/entranceController/externalCallInterface").addHeaders(headerMap).body(params).timeout(60000).execute().body();
        if (StrUtil.isNotEmpty(result)){
            CbsResponseDTO cbsResponseDTO = JSONObject.parseObject(result, CbsResponseDTO.class);
            if (null != cbsResponseDTO){
                if (CollectionUtils.isNotEmpty(cbsResponseDTO.getData())){
                    List<JSONObject> list = cbsResponseDTO.getData();
                    if (CollectionUtils.isNotEmpty(list)){
                        JSONObject jsonObject = list.get(0);
                        CbsResDataDTO dataDTO = JSON.toJavaObject(jsonObject, CbsResDataDTO.class);
                        return dataDTO;
                    }
                }
            }
        }
        return null;
    }
}
